##  Prerequisites
  * Administrator access in SAP LeanIX.
  * Access to the AWS Identity and Access Management (IAM) service in your AWS account.
  * Authentication credentials to connect SAP LeanIX to Amazon Bedrock Agents or Amazon Bedrock AgentCore. To learn how to get these values, refer to the instructions below.
    * Region code of the AWS cluster where your agents are configured
    * Access key
    * Secret access key
